@@ -4,7 +4,7 @@ import os;
 import jprops;
 import rdflib;
 
-import .miriamRegex;
+from .miriamRegex import *;
 
 # Match empty string, unprintable characters, space, and '>'
 _invalidUri = re.compile (r'(^$|[\x00-\x20>])')
